==> kubernetes-model-4.6.4-sources.jar: io/fabric8/kubernetes/api/model/apps/ControllerRevisionListFluent.java <==
package io.fabric8.kubernetes.api.model.apps;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ListMetaFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.ListMeta;
import io.fabric8.kubernetes.api.model.ListMetaBuilder;
import java.lang.StringBuffer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface ControllerRevisionListFluent<A extends ControllerRevisionListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,ControllerRevision item);
    public A setToItems(int index,ControllerRevision item);
    public A addToItems(ControllerRevision... items);
    public A addAllToItems(Collection<ControllerRevision> items);
    public A removeFromItems(ControllerRevision... items);
    public A removeAllFromItems(Collection<ControllerRevision> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<ControllerRevision> getItems();
    public List<ControllerRevision> buildItems();
    public ControllerRevision buildItem(int index);
    public ControllerRevision buildFirstItem();
    public ControllerRevision buildLastItem();
    public ControllerRevision buildMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<ControllerRevisionBuilder> predicate);
    public Boolean hasMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<ControllerRevisionBuilder> predicate);
    public A withItems(List<ControllerRevision> items);
    public A withItems(ControllerRevision... items);
    public Boolean hasItems();
    public ControllerRevisionListFluent.ItemsNested<A> addNewItem();
    public ControllerRevisionListFluent.ItemsNested<A> addNewItemLike(ControllerRevision item);
    public ControllerRevisionListFluent.ItemsNested<A> setNewItemLike(int index,ControllerRevision item);
    public ControllerRevisionListFluent.ItemsNested<A> editItem(int index);
    public ControllerRevisionListFluent.ItemsNested<A> editFirstItem();
    public ControllerRevisionListFluent.ItemsNested<A> editLastItem();
    public ControllerRevisionListFluent.ItemsNested<A> editMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<ControllerRevisionBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ListMeta getMetadata();
    public ListMeta buildMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public ControllerRevisionListFluent.MetadataNested<A> withNewMetadata();
    public ControllerRevisionListFluent.MetadataNested<A> withNewMetadataLike(ListMeta item);
    public ControllerRevisionListFluent.MetadataNested<A> editMetadata();
    public ControllerRevisionListFluent.MetadataNested<A> editOrNewMetadata();
    public ControllerRevisionListFluent.MetadataNested<A> editOrNewMetadataLike(ListMeta item);

    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ControllerRevisionFluent<ControllerRevisionListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ListMetaFluent<ControllerRevisionListFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}

==> kubernetes-model-4.9.0-sources.jar: io/fabric8/kubernetes/api/model/apps/ControllerRevisionListFluent.java <==
package io.fabric8.kubernetes.api.model.apps;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ListMetaFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.ListMeta;
import io.fabric8.kubernetes.api.model.ListMetaBuilder;
import java.lang.StringBuffer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface ControllerRevisionListFluent<A extends ControllerRevisionListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,ControllerRevision item);
    public A setToItems(int index,ControllerRevision item);
    public A addToItems(ControllerRevision... items);
    public A addAllToItems(Collection<ControllerRevision> items);
    public A removeFromItems(ControllerRevision... items);
    public A removeAllFromItems(Collection<ControllerRevision> items);
    public A removeMatchingFromItems(io.fabric8.kubernetes.api.builder.Predicate<ControllerRevisionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<ControllerRevision> getItems();
    public List<ControllerRevision> buildItems();
    public ControllerRevision buildItem(int index);
    public ControllerRevision buildFirstItem();
    public ControllerRevision buildLastItem();
    public ControllerRevision buildMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<ControllerRevisionBuilder> predicate);
    public Boolean hasMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<ControllerRevisionBuilder> predicate);
    public A withItems(List<ControllerRevision> items);
    public A withItems(ControllerRevision... items);
    public Boolean hasItems();
    public ControllerRevisionListFluent.ItemsNested<A> addNewItem();
    public ControllerRevisionListFluent.ItemsNested<A> addNewItemLike(ControllerRevision item);
    public ControllerRevisionListFluent.ItemsNested<A> setNewItemLike(int index,ControllerRevision item);
    public ControllerRevisionListFluent.ItemsNested<A> editItem(int index);
    public ControllerRevisionListFluent.ItemsNested<A> editFirstItem();
    public ControllerRevisionListFluent.ItemsNested<A> editLastItem();
    public ControllerRevisionListFluent.ItemsNested<A> editMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<ControllerRevisionBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ListMeta getMetadata();
    public ListMeta buildMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public ControllerRevisionListFluent.MetadataNested<A> withNewMetadata();
    public ControllerRevisionListFluent.MetadataNested<A> withNewMetadataLike(ListMeta item);
    public ControllerRevisionListFluent.MetadataNested<A> editMetadata();
    public ControllerRevisionListFluent.MetadataNested<A> editOrNewMetadata();
    public ControllerRevisionListFluent.MetadataNested<A> editOrNewMetadataLike(ListMeta item);

    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ControllerRevisionFluent<ControllerRevisionListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ListMetaFluent<ControllerRevisionListFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}
